/*
** Module   : UserSecurityOps.java
** Abstract : Progress 4GL compatible security interface for _User security handlers.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ----------------------------------Description---------------------------------
** 001 OM  20130913 First version, declaring the basic four methods: get/set with and without the
**                  logical database name.
*/

package com.goldencode.p2j.util;

/**
 * The common interface for the classes that emulates USERID and SETUSERID functions of P4GL.
 */
public interface UserSecurityOps
{
   /**
    * Returns the userid associated with the current connected database. If no database is
    * connected or there are at least two databases connected empty string is returned.
    *
    * @return   The current user context's userid or the empty string in the case of any problem.
    */
   public String getUserId();

   /**
    * Returns the userid associated with the current user of the given logical database.
    *
    * @param    dbname
    *           Logical database name.
    *
    * @return   The current user context's userid or the empty string in the
    *           case of any problem.
    */
   public String getUserIdFromDB(String dbname);

   /**
    * Authenticates the user for specified DB connection. Checks if the user login account match
    * the corresponding record of the _User table of the database. If there are multiple database
    * connections or none is connected, an error is issued.
    *
    * @param    userid
    *           The name of the user to set as UserID.
    * @param    password
    *           The users password.
    *
    * @return   The <code>true</code> in case of valid user match <code>false</code> otherwise.
    */
   public boolean setUserId(String userid, String password);

   /**
    * Authenticates the user for specified DB connection. Checks if the user login account match
    * the corresponding record of the _User table of the database.  If the specified database
    * is not connected, an error is issued.
    *
    *
    * @param    userid
    *           The name of the user to set as UserID.
    * @param    password
    *           The users password.
    * @param    dbname
    *           Logical database name.
    *
    * @return   The <code>true</code> in case of valid user match <code>false</code> otherwise.
    */
   public boolean setUserId(String userid, String password, String dbname);
}
